#!/bin/bash
#
# Savefile creator
# Copyright (c) alphaOS
# Written by simargl <archpup-at-gmail-dot-com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

[ "`whoami`" != "root" ] && exec gsu ${0}

# VARIABLES
export LC_ALL=C

TEXT="All of your settings and additional software that you install, 
will be stored within the save file, by default, so it can 
become quite large if not managed. I suggest you keep 
all of your documents and photos etc. in another location.

Please select desired size below.
"

MESSAGE="File $SAVEFILE_NAME created successfully! \nYou may need to update your boot options:
(changes=/path/to/savefile).
"
MESSAGES="File $SAVEFILE_NAME created successfully!  \nIt will be mounted and session will be saved. \nYou may need to update your boot options:
(changes=/path/to/savefile).
"
CHANGES=" It seems like you are already running the system with changes enabled. \n You can proceed creating a savefile but it will not be used until rebooted. 
"

ERROR="Error! File $SAVEFILE_NAME could not be created!
"
# QUESTION DIALOGS

if [ ! -f /mnt/live/etc/nochanges ]; then
yad --title="Savefile Creator" --center --text="$CHANGES" \
--image="dialog-information" --window-icon="dialog-information"
ret=$?
[[ $ret -ne 0 ]] && exit 1
fi

SETUP=`yad --title="Savefile Creator" --center --text="$TEXT" \
--text-align=center \
--window-icon="folder-system" --form  \
--field="Savefile Size   MB:NUM" "200!100..2048!5" \
--button="gtk-cancel:1" --button="gtk-ok:0"`

ret=$?
[[ $ret -ne 0 ]] && exit 1


SAVEFILE_SIZE=$(echo $SETUP | cut -d "|" -f 1 | cut -f1 -d".")
if [ ! -f /mnt/live/tmp/changes-exit ]; then

HDRV=`cat /mnt/live/etc/homedrv`
else
if grep -qv noauto /proc/cmdline; then
HDRV=`cat /mnt/live/etc/homedrv`

else
HDRV=`cat /mnt/live/etc/homedrv`
HDRV="/mnt/live/$HDRV"
fi
fi
SAVEFILE_NAME=$(yad  --center --save --confirm-overwrite="File exists.\nReplace?" --title="Savefile Creator" --filename="$HDRV/changes.dat" --height=600 --width=800 --text="Type a name for the new savefile. \nE.g. changes.dat or debsave.dat." --file )
ret=$?
[[ $ret -ne 0 ]] && exit 1

QUESTION="Do you want to create personal file $SAVEFILE_NAME 
with size of $SAVEFILE_SIZE MB?
"
INFO=`yad --title="Savefile Creator" --center --text="$QUESTION" \
--image="dialog-question" --window-icon="dialog-question" \
--button="gtk-cancel:1" --button="gtk-ok:0"`

ret=$?
[[ $ret -ne 0 ]] && exit 1

# ERROR
if [ -f $SYSTEM_DIR/$SAVEFILE_NAME ] ; then
  INFO=`yad --title="Savefile Creator" --center --text="$ERROR" \
  --image="dialog-error" --window-icon="dialog-error" \
  --button="gtk-cancel:1" --button="gtk-ok:0"`
  exit 1
fi

# MAKE SAVEFILE
cd $SYSTEM_DIR
SAVEBASE="$(basename "$SAVEFILE_NAME")"
#xterm -T "Savefile Creator" -si -sb -fg white -bg SkyBlue4 -geometry 65x14 -e "dd if=/dev/zero | bar -s ${SAVEFILE_SIZE}m | dd of=$SAVEFILE_NAME bs=1M count=$SAVEFILE_SIZE iflag=fullblock"
(dd if=/dev/zero | pv -n -s ${SAVEFILE_SIZE}m | dd of=$SAVEFILE_NAME bs=1M count=$SAVEFILE_SIZE iflag=fullblock) 2>&1 | yad --title="Savefile Creator" --center --height="100" --width="400" --progress --no-buttons --auto-close --text=" Creating $SAVEBASE... "
echo "Formatting $SAVEFILE_NAME"
yad --on-top --title="Make-Save" --text="  <span size='large' foreground='dark green'><b>*** Formatting $SAVEBASE... ***</b></span>  " --center --undecorated --no-buttons &
pd=$!	
echo y | mkfs.ext4 $SAVEFILE_NAME
echo "SAVEFILE=\"$SAVEFILE_NAME\"" > /tmp/savefile.txt
kill $pd

if [ -f /mnt/live/etc/nochanges ]; then
EXIT1=`yad --title="Savefile Creator" --center --text="$MESSAGES" \
--image="dialog-information" --window-icon="dialog-information" \
--button="gtk-ok:0"`
else
EXIT=`yad --title="Savefile Creator" --center --text="$MESSAGE" \
--image="dialog-information" --window-icon="dialog-information" \
--button="gtk-ok:0"`
fi

